@@ -28,14 +28,19 @@ struct _PpdActionClass
 {
   GObjectClass   parent_class;
 
-  PpdProbeResult (* probe)            (PpdAction  *action);
-  gboolean       (* activate_profile) (PpdAction  *action,
-                                       PpdProfile  profile,
-                                       GError    **error);
+  PpdProbeResult (* probe)            (PpdAction                   *action);
+  gboolean       (* activate_profile) (PpdAction                   *action,
+                                       PpdProfile                   profile,
+                                       GError                     **error);
+  gboolean       (* power_changed)    (PpdAction                   *action,
+                                       PpdPowerChangedReason        reason,
+                                       GError                     **error);
+
 };
 
 #ifndef __GTK_DOC_IGNORE__
 PpdProbeResult ppd_action_probe (PpdAction *action);
 gboolean ppd_action_activate_profile (PpdAction *action, PpdProfile profile, GError **error);
+gboolean ppd_action_power_changed (PpdAction *action, PpdPowerChangedReason reason, GError **error);
 const char *ppd_action_get_action_name (PpdAction *action);
 #endif
