@@ -31,7 +31,7 @@ struct _PpdDriverPlatformProfile
   gboolean has_low_power;
   GFileMonitor *lapmode_mon;
   GFileMonitor *acpi_platform_profile_mon;
-  guint acpi_platform_profile_changed_id;
+  gulong acpi_platform_profile_changed_id;
 };
 
 G_DEFINE_TYPE (PpdDriverPlatformProfile, ppd_driver_platform_profile, PPD_TYPE_DRIVER_PLATFORM)
@@ -71,7 +71,8 @@ profile_to_acpi_platform_profile_value (PpdDriverPlatformProfile *self,
     return "performance";
   }
 
-  g_assert_not_reached ();
+  g_debug ("Unhandled ACPI platform profile '%d'", profile);
+  g_return_val_if_reached (NULL);
 }
 
 static PpdProfile
@@ -90,10 +91,9 @@ acpi_platform_profile_value_to_profile (const char *str)
   case 'p':
     return PPD_PROFILE_PERFORMANCE;
   default:
-    g_debug ("Got unsupported performance_profile value '%s'", str);
+    g_debug ("Unhandled ACPI platform profile '%c'", str[0]);
+    g_return_val_if_reached (PPD_PROFILE_UNSET);
   }
-
-  return PPD_PROFILE_UNSET;
 }
 
 static PpdProfile
@@ -197,8 +197,12 @@ lapmode_changed (GFileMonitor      *monitor,
                  gpointer           user_data)
 {
   PpdDriverPlatformProfile *self = user_data;
-  g_debug (LAPMODE_SYSFS_NAME " attribute changed");
-  update_dytc_lapmode_state (self);
+
+  g_debug (LAPMODE_SYSFS_NAME " attribute changed (event: %d)", event_type);
+  g_return_if_fail (event_type != G_FILE_MONITOR_EVENT_DELETED);
+
+  if (event_type == G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT)
+    update_dytc_lapmode_state (self);
 }
 
 static void
@@ -209,12 +213,17 @@ acpi_platform_profile_changed (GFileMonitor      *monitor,
                                gpointer           user_data)
 {
   PpdDriverPlatformProfile *self = user_data;
+
   g_debug (ACPI_PLATFORM_PROFILE_PATH " changed (%d)", event_type);
   if (self->probe_result == PPD_PROBE_RESULT_DEFER) {
     g_signal_emit_by_name (G_OBJECT (self), "probe-request", 0);
     return;
   }
-  update_acpi_platform_profile_state (self);
+
+  g_return_if_fail (event_type != G_FILE_MONITOR_EVENT_DELETED);
+
+  if (event_type == G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT)
+    update_acpi_platform_profile_state (self);
 }
 
 static gboolean
@@ -224,6 +233,7 @@ ppd_driver_platform_profile_activate_profile (PpdDriver                   *drive
                                               GError                     **error)
 {
   PpdDriverPlatformProfile *self = PPD_DRIVER_PLATFORM_PROFILE (driver);
+  g_autoptr(GError) local_error = NULL;
   g_autofree char *platform_profile_path = NULL;
   const char *platform_profile_value;
 
@@ -245,8 +255,11 @@ ppd_driver_platform_profile_activate_profile (PpdDriver                   *drive
 
   g_signal_handler_block (G_OBJECT (self->acpi_platform_profile_mon), self->acpi_platform_profile_changed_id);
   platform_profile_path = ppd_utils_get_sysfs_path (ACPI_PLATFORM_PROFILE_PATH);
-  if (!ppd_utils_write (platform_profile_path, profile_to_acpi_platform_profile_value (self, profile), error)) {
-    g_debug ("Failed to write to acpi_platform_profile: %s", (* error)->message);
+  if (!ppd_utils_write (platform_profile_path,
+                        profile_to_acpi_platform_profile_value (self, profile), &local_error)) {
+    g_debug ("Failed to write to acpi_platform_profile: %s", local_error->message);
+    g_propagate_prefixed_error (error, g_steal_pointer (&local_error),
+                                "Failed to write to acpi_platform_profile: ");
     g_signal_handler_unblock (G_OBJECT (self->acpi_platform_profile_mon), self->acpi_platform_profile_changed_id);
     return FALSE;
   }
@@ -316,8 +329,8 @@ ppd_driver_platform_profile_probe (PpdDriver  *driver)
   self->lapmode_mon = ppd_utils_monitor_sysfs_attr (self->device,
                                                     LAPMODE_SYSFS_NAME,
                                                     NULL);
-  g_signal_connect (G_OBJECT (self->lapmode_mon), "changed",
-                    G_CALLBACK (lapmode_changed), self);
+  g_signal_connect_object (G_OBJECT (self->lapmode_mon), "changed",
+                           G_CALLBACK (lapmode_changed), self, 0);
   update_dytc_lapmode_state (self);
 
 out:
@@ -334,6 +347,8 @@ ppd_driver_platform_profile_finalize (GObject *object)
   PpdDriverPlatformProfile *driver;
 
   driver = PPD_DRIVER_PLATFORM_PROFILE (object);
+  g_clear_signal_handler (&driver->acpi_platform_profile_changed_id,
+                          driver->acpi_platform_profile_mon);
   g_clear_pointer (&driver->profile_choices, g_strfreev);
   g_clear_object (&driver->device);
   g_clear_object (&driver->lapmode_mon);
